@@ -36,7 +36,7 @@
 #'
 #' library(future)
 #' #need to call future::plan()
-#' plan(multisession(workers = availableCores()-1))
+#' plan(multisession(workers = parallelly::availableCores()-1))
 #'
 #' pnw_dv <- ww_dvUSGS(huc17_sites$site_no,
 #' parameter_cd = '00060',
@@ -125,6 +125,8 @@ ww_dvUSGS <- function(sites,
                          drainage_area = drainage_area*0.621371) %>%
                   add_date_counts()
 
+  usgs_raw_dv <- usgs_raw_dv %>% add_proportion()
+
   attr(usgs_raw_dv, 'wy_month') <- wy_month
   attr(usgs_raw_dv, 'parameter_cd') <- parameter_cd
   attr(usgs_raw_dv, 'stat_cd') <- stat_cd
@@ -237,7 +239,7 @@ prepping_USGSdv <- function(site_no, parameter_cd, start_date, end_date, stat_cd
 #'
 #' library(future)
 #' #need to call future::plan()
-#' plan(multisession(workers = availableCores()-1))
+#' plan(multisession(workers = parallelly::availableCores()-1))
 #'
 #' pnw_dv <- ww_dvUSGS(huc17_sites$site_no,
 #' parameter_cd = '00060',
@@ -671,7 +673,7 @@ if(isTRUE(verbose)){
 #'
 #' library(future)
 #' #need to call future::plan()
-#' plan(multisession(workers = availableCores()-1))
+#' plan(multisession(workers = parallelly::availableCores()-1))
 #'
 #' pnw_dv <- ww_dvUSGS(huc17_sites$site_no,
 #' parameter_cd = '00060',
@@ -810,7 +812,7 @@ ww_floorIVUSGS <- function(procDV,
 #'
 #' library(future)
 #' #need to call future::plan()
-#' plan(multisession(workers = availableCores()-1))
+#' plan(multisession(workers = parallelly::availableCores()-1))
 #'
 #' pnw_dv <- ww_dvUSGS(huc17_sites$site_no,
 #' parameter_cd = '00060',
